@@ -18,10 +18,6 @@ def read_am(model_path, inference_config):
     model = AllosaurusTorchModel(am_config)
 
     # load weights
-    torch_load(model, str(model_path / 'model.pt'))
-
-    # move to device
-    if inference_config.device_id >= 0:
-        model = model.cuda(inference_config.device_id)
+    torch_load(model, str(model_path / 'model.pt'), inference_config.device_id)
 
     return model
\ No newline at end of file
